==> 0.0.5.tar.gz: lib/src/custom_components/custom_button/view.dart <==
import 'package:flutter/material.dart';
import 'package:nirrti/nirrti.dart';
import 'package:nirrti/src/custom_components/custom_button/view_model.dart';

mixin ViewMixin {
  render(BuildContext context, OwlnextButtonState state) {
    return LayoutBuilder(
      builder: (BuildContext context, BoxConstraints constraints) {
        return Container(
          width: constraints.maxWidth,
          height: constraints.maxHeight == double.infinity ? 40 : constraints.maxHeight,
          alignment: Alignment.center,
          child: ButtonTheme(
            child: ElevatedButton(
              style: ElevatedButton.styleFrom(
                foregroundColor: Colors.white,
                backgroundColor: getBackground(context, state),
                shape: RoundedRectangleBorder(
                  borderRadius: Artist().defaultBorderRadius,
                ),
                minimumSize: const Size(double.infinity, double.infinity),
                disabledForegroundColor: Colors.white.withOpacity(0.4),
                disabledBackgroundColor: const Color.fromARGB(255, 65, 65, 65).withOpacity(0.4)
              ),
              onPressed: (state.isProcessing == true || state.widget.enabled == false) ? null : () { state.widget.callback(); },
              child: state.widget.child
            )
          )
        );
      }
    );
  }

  Color getBackground(BuildContext context, OwlnextButtonState state) {
    if (state.widget.customType != null) {
      return state.widget.customType!.backgroundColor;
    } else {
      switch (state.widget.type) {
        case ButtonType.classic:
          return Theme.of(context).colorScheme.primary;
        case ButtonType.delete:
          return Theme.of(context).colorScheme.onError;
        case ButtonType.save:
          return Theme.of(context).colorScheme.onPrimary;
        default:
          return Theme.of(context).colorScheme.primary;
      }
    }
  }
}

class ButtonLoader extends StatefulWidget{
  
  const ButtonLoader({super.key});

  @override
  ButtonLoaderState createState() {
    return ButtonLoaderState();
  }
}

class ButtonLoaderState extends State<ButtonLoader> with TickerProviderStateMixin {
  late AnimationController animationController;
  
  @override
  void initState() {
    animationController = AnimationController(
      vsync: this,
      duration: const Duration(seconds: 3),
    )..addListener(() {
      setState(() {});
    });
    animationController.repeat(reverse: true);
    super.initState();
  }
  
  @override
  void dispose() {
    animationController.dispose();
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    return Container(
      width: 20,
      height: 20,
      alignment: Alignment.center,
      child: CircularProgressIndicator(
        value: animationController.value,
        color: const Color.fromARGB(255, 236, 236, 236)
      )
    );
  }
}

==> 0.0.82.tar.gz: lib/src/custom_components/custom_button/view.dart <==
import 'package:flutter/material.dart';
import 'package:nirrti/nirrti.dart';
import 'package:nirrti/src/custom_components/custom_button/view_model.dart';

mixin ViewMixin {
  render(BuildContext context, OwlnextButtonState state) {
    return LayoutBuilder(
      builder: (BuildContext context, BoxConstraints constraints) {
        return Container(
          constraints: BoxConstraints(
            minWidth: state.widget.customWidth ?? constraints.maxWidth,
            maxWidth: state.widget.customWidth ?? constraints.maxWidth,
            minHeight: constraints.maxHeight == double.infinity ? 40 : constraints.maxHeight,
            maxHeight: constraints.maxHeight == double.infinity ? 40 : constraints.maxHeight,
          ),
          child: ButtonTheme(
            child: ElevatedButton(
              style: ElevatedButton.styleFrom(
                foregroundColor: Colors.white,
                backgroundColor: getBackground(context, state),
                shape: RoundedRectangleBorder(
                  borderRadius: Artist().defaultBorderRadius,
                ),
                disabledForegroundColor: Colors.white.withOpacity(0.4),
                disabledBackgroundColor: const Color.fromARGB(255, 65, 65, 65).withOpacity(0.4),
                alignment: Alignment.center,
              ),
              onPressed: (state.isProcessing == true || state.widget.enabled == false) ? null : () { state.widget.callback(); },
              child: state.widget.child
            )
          )
        );
      }
    );
  }

  Color getBackground(BuildContext context, OwlnextButtonState state) {
    if (state.widget.customType != null) {
      return state.widget.customType!.backgroundColor;
    } else {
      switch (state.widget.type) {
        case ButtonType.classic:
          return Theme.of(context).colorScheme.primary;
        case ButtonType.delete:
          return Theme.of(context).colorScheme.onError;
        case ButtonType.save:
          return Theme.of(context).colorScheme.onPrimary;
        default:
          return Theme.of(context).colorScheme.primary;
      }
    }
  }
}

class ButtonLoader extends StatefulWidget{
  
  const ButtonLoader({super.key});

  @override
  ButtonLoaderState createState() {
    return ButtonLoaderState();
  }
}

class ButtonLoaderState extends State<ButtonLoader> with TickerProviderStateMixin {
  late AnimationController animationController;
  
  @override
  void initState() {
    animationController = AnimationController(
      vsync: this,
      duration: const Duration(seconds: 3),
    )..addListener(() {
      setState(() {});
    });
    animationController.repeat(reverse: true);
    super.initState();
  }
  
  @override
  void dispose() {
    animationController.dispose();
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    return Container(
      width: 20,
      height: 20,
      alignment: Alignment.center,
      child: CircularProgressIndicator(
        value: animationController.value,
        color: const Color.fromARGB(255, 236, 236, 236)
      )
    );
  }
}
